pub struct AsyncDebouncer<T: Watcher> { /* private fields */ }

Implementations

source

impl<T: Watcher> AsyncDebouncer<T>

source

pub async fn stop(self)

source

pub fn watcher(&mut self) -> &mut dyn Watcher

source

impl<T: Watcher> AsyncDebouncer<T>

source

pub async fn new_with_opts<F: AsyncDebounceEventHandler + Send + 'static>( timeout: Duration, tick_rate: Option<Duration>, event_handler: F, config: Config ) -> Result<Self, Error>

Creates a new debounced watcher with custom configuration. The timeout specifies the amount of time that must elapse before an event is emitted, or a continuous event is sent (if there still are events incoming for the specific path). If tick_rate is set to None, then a tick rate will be selected that is less than the provided timeout.

source

impl AsyncDebouncer<RecommendedWatcher>

source

pub async fn new<F: AsyncDebounceEventHandler + Send + 'static>( timeout: Duration, tick_rate: Option<Duration>, event_handler: F ) -> Result<Self, Error>

Creates a new debounced watcher with the recommended watcher implementation. The timeout specifies the amount of time that must elapse before an event is emitted, or a continuous event is sent (if there still are events incoming for the specific path). If tick_rate is set to None, then a tick rate will be selected that is less than the provided timeout.